package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmLine;
import com.ruoyi.powerdistribution.domain.vo.PdmLineComplete;

/**
 * 可靠性馈线Service接口
 *
 * @author ruoyi
 * @date 2024-12-24
 */
public interface IPdmLineService
{
    /**
     * 查询可靠性馈线
     *
     * @param id 可靠性馈线主键
     * @return 可靠性馈线
     */
    public PdmLine selectPdmLineById(Long id);

    /**
     * 查询可靠性馈线列表
     *
     * @param pdmLine 可靠性馈线
     * @return 可靠性馈线集合
     */
    public List<PdmLine> selectPdmLineList(PdmLine pdmLine);

    /**
     * 新增可靠性馈线
     *
     * @param pdmLine 可靠性馈线
     * @return 结果
     */
    public int insertPdmLine(PdmLine pdmLine);

    /**
     * 修改可靠性馈线
     *
     * @param pdmLine 可靠性馈线
     * @return 结果
     */
    public int updatePdmLine(PdmLine pdmLine);

    /**
     * 批量删除可靠性馈线
     *
     * @param ids 需要删除的可靠性馈线主键集合
     * @return 结果
     */
    public int deletePdmLineByIds(Long[] ids);

    /**
     * 删除可靠性馈线信息
     *
     * @param id 可靠性馈线主键
     * @return 结果
     */
    public int deletePdmLineById(Long id);

    /**
     * 统计完成情况
     * @param complete
     * @return
     */
    List<PdmLineComplete> selectCompleteList(PdmLineComplete complete);
}
